.. _chp-howtoread:

How to Read the Modules Documentation
=====================================

Each chapter describes one of the main sub-packages of the :mod:`fipy`
package. The sub-package :mod:`fipy.package` can be found in the directory
:file:`fipy/package/`. In a few cases, there will be packages within
packages, *e.g.* :mod:`fipy.package.subpackage` located in
:file:`fipy/package/subpackage/`. These sub-sub-packages will not be given
their own chapters; rather, their contents will be described in the chapter
for their containing package.

.. autosummary::
   :toctree: generated
   :recursive:

   package
